Next Steps
==========

After you get started, here are some next steps to learn more about what you can
do with Coiled:

.. panels::
   :body: text-center
   :header: text-center h5 bg-white
   :footer: border-2 bg-white

   | :fa:`book-open,fa-4x`
   |
   | **View examples**
   |

   .. link-button:: examples
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   | :fa:`network-wired,fa-4x`
   |
   | **Launch and manage Dask clusters**
   |

   .. link-button:: cluster
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   | :fa:`tachometer-alt,fa-4x`
   |
   | **Generate a performance report**
   |

   .. link-button:: performance_reports
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   | :fa:`box-open,fa-4x`
   |
   | **Work with packages and environments**
   |

   .. link-button:: software_environment
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   | :fa:`users,fa-4x`
   |
   | **Manage teams, resource limits, and costs**
   |

   .. link-button:: teams
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   | :fa:`cloud,fa-4x`
   |
   | **Run Coiled on your own cloud account**
   |

   .. link-button:: backends
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   | :fa:`microchip,fa-4x`
   |
   | **Use GPUs with Coiled**
   |

   .. link-button:: gpu
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link

   ---

   | :fa:`chart-line,fa-4x`
   |
   | **View cluster analytics**
   |

   .. link-button:: analytics
      :type: ref
      :text: Learn more
      :classes: btn-full btn-block stretched-link
